/* 
This program (formats_for_nrbs_trip_dockeddays_weighted.sas) creates the formats
catalog for nrbs_trip_dockeddays_weighted.sas7bdat.

Instructions for Windows users:

1. Create a folder for your files, e.g. c:\sasfiles
2. Place nrbs_trip_dockeddays_weighted.sas7bdat and formats_for_nrbs_trip_dockeddays_weighted.sas
   in the folder
3. Edit the libname statement in formats_for_nrbs_trip_dockeddays_weighted.sas so that
   it refers to the folder, e.g.: libname library 'c:\sasfiles'
4. Open and run formats_for_nrbs_trip_dockeddays_weighted.sas.  This will create
   the formats catalog, "formats.sas7bcat" in that folder.
5. You may now use nrbs_trip_dockeddays_weighted.sas7bdat any way you
   like, for example the following program will create a frequency listing:

   libname library 'c:\sasfiles';
   proc freq data=library.nrbs_trip_dockeddays_weighted; 
      tables _all_;
   run;

   Note that by using the name "library" for your libname when inputting the 
   data, SAS will automatically look in that same location for the formats
   catalog.  Otherwise, you would need to use a "fmtsearch" option to tell
   SAS where to look for the formats catalog.
*/

libname library '';

proc format library=library;

   value V00006F 
      1 = "1-DAY"
      2 = "2-FIRST DAY"
      3 = "3-LAST DAY"
   ;
   value DKRTWO 
      97 = "97-[PHONE] DON'T KNOW"
      99 = "99-[PHONE] REFUSED"
   ;
   value NOANS 
      88 = "88-NO ANSWER"
   ;
   value V00010F 
      61 = "61-Reported No Activity"
      62 = "62-Reported Docked Day Only"
      63 = "63-Reported Water Day Only"
      64 = "64-Reported Water And Docked Day"
   ;
   value V00011F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-WASHINGTON, DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINIA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      88 = "88-THE BOAT WAS NOT IN THE UNITED STATES"
      96 = "96-OTHER (SPECIFY)"
      97 = "97-[PHONE] DON'T KNOW"
      98 = "98-[WEB] NO ANSWER"
      99 = "99-[PHONE] REFUSED"
   ;
   value BTACTIVEF 
      0 = "0- BOAT REPORTED NO ACTIVITY IN REFERENCE MONTH"
      1 = "1- BOAT REPORTED AT LEAST ONE DAY OF ACTIVITY IN REFERENCE MONTH"
   ;
   value OUTSTATEF 
      0 = "0- BOAT DID NOT TRAVEL OUT OF STATE"
      1 = "1- BOAT TRAVELED OUT OF STATE"
   ;
   value NATION 
      1 = "1- UNITED STATES"
   ;
   value V00002F 
      1 = "01-CONTINUE"
   ;
   value QUARTER 
      1 = "1- Q1"
      2 = "2- Q2"
      3 = "3- Q3"
      4 = "4- Q4"
   ;
   value V00204F 
      1 = "01-REGISTERED/YES"
      2 = "02-UNREGISTERED/NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value REGION 
      1 = "1- NORTHEAST"
      2 = "2- MIDWEST"
      3 = "3- SOUTH"
      4 = "4- WEST"
      9 = "9- PUERTO RICO"
   ;
   value $BOATTYPE 
      "01" = "01- POWERBOAT THAT IS LESS THAN 16 FEET"
      "02" = "02- 16-20 FOOT POWERBOAT"
      "03" = "03- 21-28 FOOT POWERBOAT"
      "04" = "04- POWERBOAT THAT IS GREATER THAN 28 FEET"
      "05" = "05- SAILBOAT THAT IS LESS THAN 26 FEET"
      "06" = "06- SAILBOAT THAT IS GREATER THAN 25 FEET"
      "07" = "07- PONTOON BOAT"
      "08" = "08- PERSONAL WATER CRAFT (FOR EXAMPLE, JET SKI)"
      "09" = "09- SELF PROPELLED BOAT (FOR EXAMPLE, KAYAK, CANOE, ETC.)"
      "10" = "10- RECREATIONAL BOAT"
   ;
   value $BOATTYPE1F 
      "01" = "01- ALL TYPES"
   ;
   value $BOATTYPE10F 
      "01" = "01- POWERBOAT THAT IS LESS THAN 16 FEET"
      "02" = "02- 16-20 FOOT POWERBOAT"
      "03" = "03- 21-28 FOOT POWERBOAT"
      "04" = "04- POWERBOAT THAT IS GREATER THAN 28 FEET"
      "05" = "05- SAILBOAT THAT IS LESS THAN 26 FEET"
      "06" = "06- SAILBOAT THAT IS GREATER THAN 25 FEET"
      "07" = "07- PONTOON BOAT"
      "08" = "08- PERSONAL WATER CRAFT (FOR EXAMPLE, JET SKI)"
      "09" = "09- SELF PROPELLED BOAT (FOR EXAMPLE, KAYAK, CANOE, ETC.)"
      "10" = "10- RECREATIONAL BOAT"
   ;
   value $BOATTYPE3F 
      "01" = "01- POWERBOAT/PONTOON BOAT/PWC"
      "02" = "02- CANOE/KAYAK"
      "03" = "03- SAILBOAT/ROW/INF/OTHER"
   ;
   value $BOATTYPE7F 
      "01" = "01- POWERBOAT"
      "02" = "02- SAILBOAT"
      "03" = "03- PONTOON BOAT"
      "04" = "04- PWC"
      "05" = "05- CANOE"
      "06" = "06- KAYAK"
      "07" = "07- ROW/INF/OTHER"
   ;
   value $CATX 
      "01" = "01-A POWERBOAT"
      "02" = "02-A SAILBOAT"
      "03" = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      "04" = "04-CANOE"
      "05" = "05-KAYAK"
      "06" = "06-SOMETHING ELSE"
      "97" = "97-DON'T KNOW"
      "99" = "99-REFUSED"
   ;
   value $HASMOT 
      "01" = "01-YES"
      "02" = "02-NO"
      "97" = "97-DON'T KNOW"
      "99" = "99-REFUSED"
   ;
   value $MODE 
      "P" = "P-PHONE"
      "W" = "W-WEB"
   ;
   value $MONTH 
      "01" = "01-JANUARY"
      "02" = "02-FEBRUARY"
      "03" = "03-MARCH"
      "04" = "04-APRIL"
      "05" = "05-MAY"
      "06" = "06-JUNE"
      "07" = "07-JULY"
      "08" = "08-AUGUST"
      "09" = "09-SEPTEMBER"
      "10" = "10-OCTOBER"
      "11" = "11-NOVEMBER"
      "12" = "12-DECEMBER"
   ;
   value $TPOX 
      "01" = "01-A ROWBOAT"
      "02" = "02-AN INFLATABLE"
      "03" = "03-NEITHER"
      "97" = "97-DON'T KNOW"
      "99" = "99-REFUSED"
   ;
run;
